@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2007 Members of the libquicktime project.
+ Copyright (C) 2002-2010 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -33,6 +33,9 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#define LQT_COLR_NCLC 0x6E636C63
+#define LQT_COLR_PROF 0x70726F66
+
 /* Fine tuning of quicktime atoms. Use with caution */
 
 /** \defgroup atoms Fine tuning of quicktime atoms
