@@ -44,7 +44,6 @@ typedef struct
   int initialized;
   faacEncHandle enc;
 
-  int chunk_started;
   quicktime_atom_t chunk_atom;
 
   int encoder_delay;
@@ -56,9 +55,9 @@ typedef struct
   } quicktime_faac_codec_t;
 
 
-static int delete_codec(quicktime_audio_map_t *track_map)
+static int delete_codec(quicktime_codec_t *codec_base)
   {
-  quicktime_faac_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_faac_codec_t *codec = codec_base->priv;
   if(codec->sample_buffer)
     free(codec->sample_buffer);
   if(codec->chunk_buffer)
@@ -74,8 +73,8 @@ static int encode_frame(quicktime_t *file,
   int imax, i;
   int bytes_encoded;
   int result;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_faac_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_faac_codec_t *codec = track_map->codec->priv;
   quicktime_trak_t * trak = track_map->track;
   /* Normalize input to 16 bit int */
 
@@ -111,12 +110,8 @@ static int encode_frame(quicktime_t *file,
   
   /* Write these data */
 
-  if(!codec->chunk_started)
-    {
-    codec->chunk_started = 1;
-    lqt_start_audio_vbr_chunk(file, track);
-    quicktime_write_chunk_header(file, trak, &codec->chunk_atom);
-    }
+  if(file->write_trak != trak)
+    quicktime_write_chunk_header(file, trak);
   
   lqt_start_audio_vbr_frame(file, track);
   result = !quicktime_write_data(file, codec->chunk_buffer,
@@ -132,12 +127,82 @@ static int encode_frame(quicktime_t *file,
   return 1;
   }
 
+static void setup_header(quicktime_t *file, int track,
+                         const uint8_t * header, int header_len)
+  {
+  quicktime_esds_t * esds;
+  uint8_t mp4a_atom[4];
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_trak_t * trak = track_map->track;
+
+  lqt_init_vbr_audio(file, track);
+  
+  esds = quicktime_set_esds(trak, header, header_len);
+
+  quicktime_set_frma(trak, "mp4a");
+
+  mp4a_atom[0] = 0x00;
+  mp4a_atom[1] = 0x00;
+  mp4a_atom[2] = 0x00;
+  mp4a_atom[3] = 0x00;
+    
+  quicktime_wave_set_user_atom(trak, "mp4a", mp4a_atom, 4);
+#if 0
+  quicktime_set_stsd_audio_v2(&trak->mdia.minf.stbl.stsd.table[0],
+                              0x00000002, /* formatSpecificFlags */
+                              0, /* constBytesPerAudioPacket */
+                              codec->samples_per_frame /* constLPCMFramesPerAudioPacket */);
+#else
+  quicktime_set_stsd_audio_v1(&trak->mdia.minf.stbl.stsd.table[0],
+                              1024, // uint32_t samples_per_packet,
+                              768, // uint32_t bytes_per_packet,
+                              1536, // uint32_t bytes_per_frame,
+                              0 // uint32_t bytes_per_sample
+                              );
+#endif
+  trak->mdia.minf.stbl.stsd.table[0].sample_size = 16;
+    
+  esds->version         = 0;
+  esds->flags           = 0;
+    
+  esds->esid            = 0;
+  esds->stream_priority = 0;
+    
+  esds->objectTypeId    = 64; /* MPEG-4 audio */
+  esds->streamType      = 0x15; /* from qt4l and Autumns Child.m4a */
+  //    esds->bufferSizeDB    = 64000; /* Hopefully not important :) */
+  esds->bufferSizeDB    = 6144;
+  /* Maybe correct these later? */
+  esds->maxBitrate      = 128000;
+  esds->avgBitrate      = 128000;
+
+  /* No idea if the following is right but other AAC LC files have the same */
+
+#if 0
+  switch(enc_config->aacObjectType)
+    {
+    case LOW:
+      // "High Quality Audio Profile @ Level 2"
+      file->moov.iods.audioProfileId  = 0x0f;
+      break;
+    case SSR:
+      file->moov.iods.audioProfileId  = 0x0f;
+      break;
+    default:
+      file->moov.iods.audioProfileId  = 0x0f;
+      break;
+    }
+#else
+  file->moov.iods.audioProfileId  = 0x0f;
+#endif
+  
+  }
+
 static int encode(quicktime_t *file, 
                   void *_input,
                   long samples,
                   int track)
   {
-  quicktime_esds_t * esds;
   int samples_read;
   int samples_to_copy;
   
@@ -149,14 +214,12 @@ static int encode(quicktime_t *file,
   uint8_t * decoderConfig;
   unsigned long decoderConfigLen;
   
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_faac_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_faac_codec_t *codec = track_map->codec->priv;
   quicktime_trak_t * trak = track_map->track;
-  uint8_t mp4a_atom[4];
   
   if(!codec->initialized)
     {
-    lqt_init_vbr_audio(file, track);
     /* Create encoder */
     
     codec->enc = faacEncOpen(track_map->samplerate,
@@ -175,7 +238,8 @@ static int encode(quicktime_t *file,
     
     if(!faacEncSetConfiguration(codec->enc, enc_config))
       {
-      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Setting encode parameters failed, check settings");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN,
+              "Setting encode parameters failed, check settings");
       }
     /* Allocate buffers */
 
@@ -198,63 +262,11 @@ static int encode(quicktime_t *file,
     
     faacEncGetDecoderSpecificInfo(codec->enc, &decoderConfig,
                                   &decoderConfigLen);
+
+    setup_header(file, track,  decoderConfig, decoderConfigLen);
     
-    esds = quicktime_set_esds(trak,
-                              decoderConfig,
-                              decoderConfigLen);
     free(decoderConfig);
-
-    quicktime_set_frma(trak, "mp4a");
-
-    mp4a_atom[0] = 0x00;
-    mp4a_atom[1] = 0x00;
-    mp4a_atom[2] = 0x00;
-    mp4a_atom[3] = 0x00;
     
-    quicktime_wave_set_user_atom(trak, "mp4a", mp4a_atom, 4);
-#if 0
-    quicktime_set_stsd_audio_v2(&(trak->mdia.minf.stbl.stsd.table[0]),
-                                0x00000002, /* formatSpecificFlags */
-                                0, /* constBytesPerAudioPacket */
-                                codec->samples_per_frame /* constLPCMFramesPerAudioPacket */);
-#else
-    quicktime_set_stsd_audio_v1(&(trak->mdia.minf.stbl.stsd.table[0]),
-                                1024, // uint32_t samples_per_packet,
-                                768, // uint32_t bytes_per_packet,
-                                1536, // uint32_t bytes_per_frame,
-                                0 // uint32_t bytes_per_sample
-                                );
-#endif
-    trak->mdia.minf.stbl.stsd.table[0].sample_size = 16;
-    
-    esds->version         = 0;
-    esds->flags           = 0;
-    
-    esds->esid            = 0;
-    esds->stream_priority = 0;
-    
-    esds->objectTypeId    = 64; /* MPEG-4 audio */
-    esds->streamType      = 0x15; /* from qt4l and Autumns Child.m4a */
-    //    esds->bufferSizeDB    = 64000; /* Hopefully not important :) */
-    esds->bufferSizeDB    = 6144;
-    /* Maybe correct these later? */
-    esds->maxBitrate      = 128000;
-    esds->avgBitrate      = 128000;
-
-    /* No idea if the following is right but other AAC LC files have the same */
-    switch(enc_config->aacObjectType)
-      {
-      case LOW:
-        // "High Quality Audio Profile @ Level 2"
-        file->moov.iods.audioProfileId  = 0x0f;
-        break;
-      case SSR:
-        file->moov.iods.audioProfileId  = 0x0f;
-        break;
-      default:
-        file->moov.iods.audioProfileId  = 0x0f;
-        break;
-      }
     }
   
   /* Encode samples */
@@ -262,8 +274,6 @@ static int encode(quicktime_t *file,
 
   input = (float*)_input;
   
-  
-  
   while(samples_read < samples)
     {
     /* Put samples into sample buffer */
@@ -272,7 +282,8 @@ static int encode(quicktime_t *file,
     if(samples_read + samples_to_copy > samples)
       samples_to_copy = samples - samples_read;
 
-    memcpy(codec->sample_buffer + track_map->channels * codec->sample_buffer_size,
+    memcpy(codec->sample_buffer +
+           track_map->channels * codec->sample_buffer_size,
            input + samples_read * track_map->channels,
            samples_to_copy * track_map->channels * sizeof(float));
     
@@ -286,15 +297,10 @@ static int encode(quicktime_t *file,
     }
 
   /* Finalize audio chunk */
-  if(codec->chunk_started)
+  if(file->write_trak == trak)
     {
-    quicktime_write_chunk_footer(file,
-                                 trak,
-                                 track_map->cur_chunk,
-                                 &codec->chunk_atom,
-                                 track_map->vbr_num_frames);
+    quicktime_write_chunk_footer(file, trak);
     track_map->cur_chunk++;
-    codec->chunk_started = 0;
     }
   return 0;
   }
@@ -304,8 +310,8 @@ static int set_parameter(quicktime_t *file,
                          const char *key, 
                          const void *value)
   {
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_faac_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_faac_codec_t *codec = track_map->codec->priv;
     
   if(!strcasecmp(key, "faac_bitrate"))
     codec->bitrate = *(int*)value;
@@ -328,8 +334,8 @@ static int set_parameter(quicktime_t *file,
 static int flush(quicktime_t *file, int track)
   {
   int i;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_faac_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_faac_codec_t *codec = track_map->codec->priv;
   quicktime_trak_t * trak = track_map->track;
 
   if(!codec->initialized)
@@ -350,81 +356,102 @@ static int flush(quicktime_t *file, int track)
     ;
   
   /* Finalize audio chunk */
-  if(codec->chunk_started)
+  if(file->write_trak == trak)
     {
-    quicktime_write_chunk_footer(file,
-                                 trak,
-                                 track_map->cur_chunk,
-                                 &codec->chunk_atom,
-                                 track_map->vbr_num_frames);
+    quicktime_write_chunk_footer(file, trak);
     track_map->cur_chunk++;
-    codec->chunk_started = 0;
     return 1;
     }
   return 0;
   }
 
-void quicktime_init_codec_faac(quicktime_audio_map_t *track_map)
+static int writes_compressed(lqt_file_type_t type, const lqt_compression_info_t * ci)
+  {
+  if(!(type & (LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_MP4 |
+               LQT_FILE_M4A | LQT_FILE_3GP)))
+    return 0;
+
+  if(!ci->global_header_len)
+    return 0;
+  
+  return 1;
+  }
+
+static int init_compressed(quicktime_t * file, int track)
+  {
+  setup_header(file, track,
+               file->atracks[track].ci.global_header,
+               file->atracks[track].ci.global_header_len);
+  return 0;
+  }
+
+void quicktime_init_codec_faac(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
   {
-  quicktime_codec_t *codec_base = (quicktime_codec_t*)track_map->codec;
   quicktime_faac_codec_t *codec;
   
   /* Init public items */
-  codec_base->priv = calloc(1, sizeof(quicktime_faac_codec_t));
-  codec_base->delete_acodec = delete_codec;
+  codec = calloc(1, sizeof(*codec));
+  
+  codec_base->priv = codec;
+  codec_base->delete_codec = delete_codec;
   codec_base->encode_audio = encode;
   codec_base->set_parameter = set_parameter;
   codec_base->flush = flush;
+  codec_base->writes_compressed = writes_compressed;
+  codec_base->init_compressed   = init_compressed;
   
-  codec = codec_base->priv;
-
   codec->bitrate = 0;
   codec->quality = 100;
-  
-  track_map->sample_format = LQT_SAMPLE_FLOAT;
 
-  if(track_map->channels <= 6)
+  if(!atrack)
+    return;
+  
+  atrack->sample_format = LQT_SAMPLE_FLOAT;
+
+  if(atrack->channels <= 6)
     {
     /* Set default AAC channel setup */
-    track_map->channel_setup = calloc(track_map->channels,
-                                      sizeof(*track_map->channel_setup));
+    atrack->channel_setup = calloc(atrack->channels,
+                                      sizeof(*atrack->channel_setup));
 
-    switch(track_map->channels)
+    switch(atrack->channels)
       {
       case 1:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
         break;
       case 2:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_LEFT;
-        track_map->channel_setup[1] = LQT_CHANNEL_FRONT_RIGHT;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_LEFT;
+        atrack->channel_setup[1] = LQT_CHANNEL_FRONT_RIGHT;
         break;
       case 3:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
-        track_map->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
-        track_map->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
+        atrack->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
+        atrack->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
         break;
       case 4:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
-        track_map->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
-        track_map->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
-        track_map->channel_setup[3] = LQT_CHANNEL_BACK_CENTER;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
+        atrack->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
+        atrack->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
+        atrack->channel_setup[3] = LQT_CHANNEL_BACK_CENTER;
         break;
       case 5:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
-        track_map->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
-        track_map->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
-        track_map->channel_setup[3] = LQT_CHANNEL_BACK_LEFT;
-        track_map->channel_setup[4] = LQT_CHANNEL_BACK_RIGHT;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
+        atrack->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
+        atrack->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
+        atrack->channel_setup[3] = LQT_CHANNEL_BACK_LEFT;
+        atrack->channel_setup[4] = LQT_CHANNEL_BACK_RIGHT;
         break;
       case 6:
-        track_map->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
-        track_map->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
-        track_map->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
-        track_map->channel_setup[3] = LQT_CHANNEL_BACK_LEFT;
-        track_map->channel_setup[4] = LQT_CHANNEL_BACK_RIGHT;
-        track_map->channel_setup[5] = LQT_CHANNEL_LFE;
+        atrack->channel_setup[0] = LQT_CHANNEL_FRONT_CENTER;
+        atrack->channel_setup[1] = LQT_CHANNEL_FRONT_LEFT;
+        atrack->channel_setup[2] = LQT_CHANNEL_FRONT_RIGHT;
+        atrack->channel_setup[3] = LQT_CHANNEL_BACK_LEFT;
+        atrack->channel_setup[4] = LQT_CHANNEL_BACK_RIGHT;
+        atrack->channel_setup[5] = LQT_CHANNEL_LFE;
         break;
       }
-    quicktime_set_chan(track_map);
+    quicktime_set_chan(atrack);
     }
   }
