@@ -89,7 +89,7 @@ static int mpeg_samplerates[3][3] = {
 
 /* Header detection stolen from the mpg123 plugin of xmms */
 
-static int header_check(uint32_t head)
+static int mpa_header_check(uint32_t head)
   {
   if ((head & 0xffe00000) != 0xffe00000)
     return 0;
@@ -133,15 +133,16 @@ typedef struct
   int channel_mode;
   int mode;
   int samples_per_frame;
-  } mpeg_header;
+  } mpa_header;
 
-static int header_equal(const mpeg_header * h1, const mpeg_header * h2)
+static int mpa_header_equal(const mpa_header * h1, const mpa_header * h2)
   {
   return ((h1->layer == h2->layer) && (h1->version == h2->version) &&
           (h1->samplerate == h2->samplerate));
   }
 
-static int decode_header(mpeg_header * h, uint8_t * ptr, const mpeg_header * ref)
+static int mpa_decode_header(mpa_header * h, uint8_t * ptr,
+                             const mpa_header * ref)
   {
   uint32_t header;
   int index;
@@ -151,7 +152,7 @@ static int decode_header(mpeg_header * h, uint8_t * ptr, const mpeg_header * ref
   h->frame_bytes = 0;
   header =
     ptr[3] | (ptr[2] << 8) | (ptr[1] << 16) | (ptr[0] << 24);
-  if(!header_check(header))
+  if(!mpa_header_check(header))
     return 0;
   index = (header & MPEG_MODE_MASK) >> 6;
   switch(index)
@@ -266,11 +267,148 @@ static int decode_header(mpeg_header * h, uint8_t * ptr, const mpeg_header * ref
 
   /* Check against reference header */
 
-  if(ref && !header_equal(ref, h))
+  if(ref && !mpa_header_equal(ref, h))
     return 0;
   return 1;
   }
 
+/* AC3 header */
+
+typedef struct
+  {
+  /* Primary */
+  int fscod;
+  int frmsizecod;
+  int bsid;
+  int bsmod;
+  int acmod;
+  int cmixlev;
+  int surmixlev;
+  int dsurmod;
+  int lfeon;
+  
+  /* Secondary */
+  int frame_bytes;
+  int bitrate;
+  } a52_header;
+
+#define PTR_2_32BE(p) \
+((*(p) << 24) | \
+(*(p+1) << 16) | \
+(*(p+2) << 8) | \
+*(p+3))
+
+static inline int get_bits(uint32_t * bits, int num)
+  {
+  int ret;
+  
+  ret = (*bits) >> (32 - num);
+  (*bits) <<= num;
+  
+  return ret;
+  }
+
+#define A52_FRAME_SAMPLES 1536
+
+/* Tables from ffmpeg (ac3tab.c) */
+static const uint16_t ac3_frame_size_tab[38][3] =
+  {
+    { 64,   69,   96   },
+    { 64,   70,   96   },
+    { 80,   87,   120  },
+    { 80,   88,   120  },
+    { 96,   104,  144  },
+    { 96,   105,  144  },
+    { 112,  121,  168  },
+    { 112,  122,  168  },
+    { 128,  139,  192  },
+    { 128,  140,  192  },
+    { 160,  174,  240  },
+    { 160,  175,  240  },
+    { 192,  208,  288  },
+    { 192,  209,  288  },
+    { 224,  243,  336  },
+    { 224,  244,  336  },
+    { 256,  278,  384  },
+    { 256,  279,  384  },
+    { 320,  348,  480  },
+    { 320,  349,  480  },
+    { 384,  417,  576  },
+    { 384,  418,  576  },
+    { 448,  487,  672  },
+    { 448,  488,  672  },
+    { 512,  557,  768  },
+    { 512,  558,  768  },
+    { 640,  696,  960  },
+    { 640,  697,  960  },
+    { 768,  835,  1152 },
+    { 768,  836,  1152 },
+    { 896,  975,  1344 },
+    { 896,  976,  1344 },
+    { 1024, 1114, 1536 },
+    { 1024, 1115, 1536 },
+    { 1152, 1253, 1728 },
+    { 1152, 1254, 1728 },
+    { 1280, 1393, 1920 },
+    { 1280, 1394, 1920 },
+  };
+
+const uint16_t ac3_bitrate_tab[19] =
+  {
+    32, 40, 48, 56, 64, 80, 96, 112, 128,
+    160, 192, 224, 256, 320, 384, 448, 512, 576, 640
+  };
+
+static int a52_header_read(a52_header * ret, uint8_t * buf)
+  {
+  int shift;
+  uint32_t bits;
+  memset(ret, 0, sizeof(*ret));
+
+  /* Check syncword */
+  if((buf[0] != 0x0b) || (buf[1] != 0x77))
+    return 0;
+
+  /* Skip syncword & crc */
+  buf += 4;
+
+  bits = PTR_2_32BE(buf);
+  
+  ret->fscod      = get_bits(&bits, 2);
+  ret->frmsizecod = get_bits(&bits, 6);
+
+  if(ret->frmsizecod > 37)
+    return 0;
+  
+  ret->bsid       = get_bits(&bits, 5);
+
+  if(ret->bsid >= 12)
+    return 0;
+  
+  ret->bsmod      = get_bits(&bits, 3);
+  ret->acmod      = get_bits(&bits, 3);
+
+  if((ret->acmod & 0x01) && (ret->acmod != 0x01))
+    ret->cmixlev = get_bits(&bits, 2);
+  if(ret->acmod & 0x04)
+    ret->surmixlev = get_bits(&bits, 2);
+  if(ret->acmod == 0x02)
+    ret->dsurmod = get_bits(&bits, 2);
+  ret->lfeon = get_bits(&bits, 1);
+
+  /* Secondary variables */
+
+  shift = ret->bsid - 8;
+  if(shift < 0)
+    shift = 0;
+
+  ret->bitrate = (ac3_bitrate_tab[ret->frmsizecod>>1] * 1000) >> shift;
+  ret->frame_bytes = ac3_frame_size_tab[ret->frmsizecod][ret->fscod] * 2;
+  return 1;
+  }
+
+/* Codec */
+
 typedef struct
   {
   AVCodecContext * avctx;
@@ -296,28 +434,35 @@ typedef struct
   int64_t sample_buffer_start;
   int64_t sample_buffer_end;
 
-  mpeg_header mph;
-  int have_mpeg_header;
+  mpa_header mph;
+  int have_mpa_header;
 
   uint8_t * extradata;
 #if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
   AVPacket pkt;
 #endif
+
+  int64_t pts; /* For reading compressed packets */
+
+  int header_written;
+  
   } quicktime_ffmpeg_audio_codec_t;
 
-static int lqt_ffmpeg_delete_audio(quicktime_audio_map_t *vtrack)
+static int lqt_ffmpeg_delete_audio(quicktime_codec_t *codec_base)
   {
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-  
+  quicktime_ffmpeg_audio_codec_t * codec = codec_base->priv;
   if(codec->avctx)
     {
     if(codec->initialized)
       avcodec_close(codec->avctx);
     av_free(codec->avctx);
     }
-  if(codec->sample_buffer) free(codec->sample_buffer);
-  if(codec->chunk_buffer)  free(codec->chunk_buffer);
-  if(codec->extradata) free(codec->extradata); 
+  if(codec->sample_buffer)
+    free(codec->sample_buffer);
+  if(codec->chunk_buffer)
+    free(codec->chunk_buffer);
+  if(codec->extradata)
+    free(codec->extradata); 
   free(codec);
   return 0;
   }
@@ -327,7 +472,7 @@ static int set_parameter(quicktime_t *file,
                   const char *key, 
                   const void *value)
   {
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)file->atracks[track].codec)->priv;
+  quicktime_ffmpeg_audio_codec_t *codec = file->atracks[track].codec->priv;
   lqt_ffmpeg_set_parameter(codec->avctx, key, value);
   return 0;
   }
@@ -341,8 +486,8 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
   int packet_size, packet_samples;
   int frame_bytes;
   int new_samples;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
 
   chunk_packets = lqt_audio_num_vbr_packets(file, track, track_map->cur_chunk, &num_samples);
 
@@ -363,7 +508,7 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
   for(i = 0; i < chunk_packets; i++)
     {
     packet_size = lqt_audio_read_vbr_packet(file, track, track_map->cur_chunk, i,
-                                            &(codec->chunk_buffer), &(codec->chunk_buffer_alloc),
+                                            &codec->chunk_buffer, &codec->chunk_buffer_alloc,
                                             &packet_samples);
     if(!packet_size)
       return 0;
@@ -381,16 +526,16 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
     codec->pkt.size = packet_size + FF_INPUT_BUFFER_PADDING_SIZE;
     
     frame_bytes = avcodec_decode_audio3(codec->avctx,
-                                        &(codec->sample_buffer[track_map->channels *
+                                        &codec->sample_buffer[track_map->channels *
                                                                (codec->sample_buffer_end -
-                                                                codec->sample_buffer_start)]),
+                                                                codec->sample_buffer_start)],
                                         &bytes_decoded,
                                         &codec->pkt);
 #else
     frame_bytes =
       DECODE_FUNC(codec->avctx,
-                  &(codec->sample_buffer[track_map->channels *
-                                         (codec->sample_buffer_end - codec->sample_buffer_start)]),
+                  &codec->sample_buffer[track_map->channels *
+                                         (codec->sample_buffer_end - codec->sample_buffer_start)],
                   &bytes_decoded,
                   codec->chunk_buffer,
                   packet_size + FF_INPUT_BUFFER_PADDING_SIZE);
@@ -411,7 +556,7 @@ static int decode_chunk_vbr(quicktime_t * file, int track)
 
 static int decode_chunk(quicktime_t * file, int track)
   {
-  mpeg_header mph;
+  mpa_header mph;
     
   int frame_bytes;
   int num_samples;
@@ -420,15 +565,15 @@ static int decode_chunk(quicktime_t * file, int track)
   int bytes_decoded;
   int bytes_used, bytes_skipped;
   int64_t chunk_size;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
 
   /* Read chunk */
   
   chunk_size = lqt_append_audio_chunk(file,
                                       track, track_map->cur_chunk,
-                                      &(codec->chunk_buffer),
-                                      &(codec->chunk_buffer_alloc),
+                                      &codec->chunk_buffer,
+                                      &codec->chunk_buffer_alloc,
                                       codec->bytes_in_chunk_buffer);
 
   
@@ -439,7 +584,7 @@ static int decode_chunk(quicktime_t * file, int track)
     if((codec->avctx->codec_id == CODEC_ID_MP3) &&
        (codec->bytes_in_chunk_buffer >= 4))
       {
-      if(!decode_header(&mph, codec->chunk_buffer, (const mpeg_header*)0))
+      if(!mpa_decode_header(&mph, codec->chunk_buffer, (const mpa_header*)0))
         {
         lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Decode header failed");
         return 0;
@@ -519,16 +664,16 @@ static int decode_chunk(quicktime_t * file, int track)
       bytes_skipped = 0;
       while(1)
         {
-        if(!codec->have_mpeg_header)
+        if(!codec->have_mpa_header)
           {
-          if(decode_header(&mph, &(codec->chunk_buffer[bytes_used]), NULL))
+          if(mpa_decode_header(&mph, &codec->chunk_buffer[bytes_used], NULL))
             {
-            memcpy(&(codec->mph), &mph, sizeof(mph));
-            codec->have_mpeg_header = 1;
+            memcpy(&codec->mph, &mph, sizeof(mph));
+            codec->have_mpa_header = 1;
             break;
             }
           }
-        else if(decode_header(&mph, &(codec->chunk_buffer[bytes_used]), &(codec->mph)))
+        else if(mpa_decode_header(&mph, &codec->chunk_buffer[bytes_used], &codec->mph))
           break;
         
         bytes_used++;
@@ -551,8 +696,6 @@ static int decode_chunk(quicktime_t * file, int track)
                   codec->chunk_buffer + bytes_used, codec->bytes_in_chunk_buffer);
         return 1;
         }
-      
-      
       }
 
     /*
@@ -571,22 +714,22 @@ static int decode_chunk(quicktime_t * file, int track)
 #endif
 
 #if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
-    codec->pkt.data = &(codec->chunk_buffer[bytes_used]);
+    codec->pkt.data = &codec->chunk_buffer[bytes_used];
     codec->pkt.size = codec->bytes_in_chunk_buffer + FF_INPUT_BUFFER_PADDING_SIZE;
     
     frame_bytes =
       avcodec_decode_audio3(codec->avctx,
-                            &(codec->sample_buffer[track_map->channels *
-                                                   (codec->sample_buffer_end - codec->sample_buffer_start)]),
+                            &codec->sample_buffer[track_map->channels *
+                                                   (codec->sample_buffer_end - codec->sample_buffer_start)],
                             &bytes_decoded,
                             &codec->pkt);
 #else
     frame_bytes =
       DECODE_FUNC(codec->avctx,
-                  &(codec->sample_buffer[track_map->channels *
-                                         (codec->sample_buffer_end - codec->sample_buffer_start)]),
+                  &codec->sample_buffer[track_map->channels *
+                                        (codec->sample_buffer_end - codec->sample_buffer_start)],
                   &bytes_decoded,
-                  &(codec->chunk_buffer[bytes_used]),
+                  &codec->chunk_buffer[bytes_used],
                   codec->bytes_in_chunk_buffer + FF_INPUT_BUFFER_PADDING_SIZE);
 #endif
     if(frame_bytes < 0)
@@ -603,7 +746,8 @@ static int decode_chunk(quicktime_t * file, int track)
       if(codec->avctx->codec_id == CODEC_ID_MP3)
         {
         /* For mp3, bytes_decoded < 0 means, that the frame should be muted */
-        memset(&(codec->sample_buffer[track_map->channels * (codec->sample_buffer_end - codec->sample_buffer_start)]),
+        memset(&codec->sample_buffer[track_map->channels * (codec->sample_buffer_end -
+                                                            codec->sample_buffer_start)],
                0, 2 * mph.samples_per_frame * track_map->channels);
         
         codec->sample_buffer_end += mph.samples_per_frame * track_map->channels;
@@ -654,6 +798,85 @@ static int decode_chunk(quicktime_t * file, int track)
   return samples_decoded;
   }
 
+static void init_compression_info(quicktime_t *file, int track)
+  {
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
+
+  if((codec->decoder->id == CODEC_ID_MP2) ||
+     (codec->decoder->id == CODEC_ID_MP3))
+    {
+    mpa_header h;
+    uint32_t header;
+    uint8_t * ptr;
+    int chunk_size;
+    
+    chunk_size = lqt_append_audio_chunk(file,
+                                        track, track_map->cur_chunk,
+                                        &codec->chunk_buffer,
+                                        &codec->chunk_buffer_alloc,
+                                        codec->bytes_in_chunk_buffer);
+
+    if(chunk_size + codec->bytes_in_chunk_buffer < 4)
+      return;
+
+    ptr = codec->chunk_buffer;
+    while(1)
+      {
+      header =
+        ptr[3] | (ptr[2] << 8) | (ptr[1] << 16) | (ptr[0] << 24);
+      if(mpa_header_check(header))
+        break;
+
+      ptr++;
+      if(ptr - codec->chunk_buffer > codec->bytes_in_chunk_buffer - 4)
+        return;
+      }
+    
+    if(!mpa_decode_header(&h, ptr, NULL))
+      return;
+
+    if(h.layer == 2)
+      track_map->ci.id = LQT_COMPRESSION_MP2;
+    else if(h.layer == 3)
+      track_map->ci.id = LQT_COMPRESSION_MP3;
+    
+    if(lqt_audio_is_vbr(file, track))
+      track_map->ci.bitrate = -1;
+    else
+      track_map->ci.bitrate = h.bitrate;
+    }
+  else if(codec->decoder->id == CODEC_ID_AC3)
+    {
+    a52_header h;
+    uint8_t * ptr;
+    int chunk_size;
+
+    chunk_size = lqt_append_audio_chunk(file,
+                                        track, track_map->cur_chunk,
+                                        &codec->chunk_buffer,
+                                        &codec->chunk_buffer_alloc,
+                                        codec->bytes_in_chunk_buffer);
+
+    if(chunk_size + codec->bytes_in_chunk_buffer < 8)
+      return;
+    
+    ptr = codec->chunk_buffer;
+    while(1)
+      {
+      if(a52_header_read(&h, ptr))
+        break;
+      
+      ptr++;
+      if(ptr - codec->chunk_buffer > codec->bytes_in_chunk_buffer - 8)
+        return;
+      }
+    
+    track_map->ci.bitrate = h.bitrate;
+    track_map->ci.id = LQT_COMPRESSION_AC3;
+    }
+  }
+
 static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long samples, int track)
   {
   uint8_t * header;
@@ -662,8 +885,8 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
   int samples_decoded;
   //  int result = 0;
   int64_t chunk_sample; /* For seeking only */
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
   int channels = file->atracks[track].channels;
   //  int64_t total_samples;
 
@@ -673,13 +896,13 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
 
   if(!output) /* Global initialization */
     {
+    init_compression_info(file, track);
     return 0;
     }
   
   /* Initialize codec */
   if(!codec->initialized)
     {
-
     /* Set some mandatory variables */
     codec->avctx->channels        = quicktime_track_channels(file, track);
     codec->avctx->sample_rate     = quicktime_sample_rate(file, track);
@@ -730,7 +953,7 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
       }
 
     
-    //    memcpy(&(codec->com.ffcodec_enc), &(codec->com.params), sizeof(AVCodecContext));
+    //    memcpy(&codec->com.ffcodec_enc, &codec->com.params, sizeof(AVCodecContext));
    
     codec->avctx->codec_id = codec->decoder->id;
     codec->avctx->codec_type = codec->decoder->type;
@@ -755,12 +978,12 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
       {
       if(lqt_audio_is_vbr(file, track))
         lqt_chunk_of_sample_vbr(&chunk_sample,
-                                &(track_map->cur_chunk),
+                                &track_map->cur_chunk,
                                 track_map->track,
                                 track_map->current_position);
       else
         quicktime_chunk_of_sample(&chunk_sample,
-                                  &(track_map->cur_chunk),
+                                  &track_map->cur_chunk,
                                   track_map->track,
                                   track_map->current_position);
       codec->sample_buffer_start = chunk_sample;
@@ -787,7 +1010,7 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
       samples_to_move = codec->sample_buffer_end - track_map->current_position;
 
       memmove(codec->sample_buffer,
-              &(codec->sample_buffer[samples_to_skip * channels]),
+              &codec->sample_buffer[samples_to_skip * channels],
               samples_to_move * channels * sizeof(int16_t));
       }
     codec->sample_buffer_start += samples_to_skip;
@@ -844,15 +1067,54 @@ static int lqt_ffmpeg_decode_audio(quicktime_t *file, void * output, long sample
  *   Encoding part
  */
 
+static void create_dac3_atom(quicktime_t * file, int track, uint8_t * buf)
+  {
+  uint32_t tmp;
+  uint8_t dac3_data[3];
+  a52_header header;
+  quicktime_trak_t *trak = file->atracks[track].track;
+  
+  if(a52_header_read(&header, buf))
+    {
+    tmp = header.fscod;
+
+    tmp <<= 5;
+    tmp |= header.bsid;
+    
+    tmp <<= 3;
+    tmp |= header.bsmod;
+
+    tmp <<= 3;
+    tmp |= header.acmod;
+
+    tmp <<= 1;
+    tmp |= header.lfeon;
+
+    tmp <<= 5;
+    tmp |= header.frmsizecod >> 1;
+
+    tmp <<= 5;
+
+    dac3_data[0] = tmp >> 16;
+    dac3_data[1] = (tmp >>  8) & 0xff;
+    dac3_data[2] = tmp & 0xff;
+    
+    quicktime_user_atoms_add_atom(&trak->mdia.minf.stbl.stsd.table[0].user_atoms,
+                                  "dac3", dac3_data,
+                                  sizeof(dac3_data));
+    }
+  
+  }
+
+
 static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
                             long samples, int track)
   {
   int result = -1;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_ffmpeg_audio_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
   quicktime_trak_t *trak = track_map->track;
   int channels = file->atracks[track].channels;
-  quicktime_atom_t chunk_atom;
   int frame_bytes;
   int samples_done = 0;
   int samples_encoded;
@@ -875,35 +1137,17 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
     codec->initialized = 1;
 
     /* One frame is: bitrate * frame_samples / (samplerate * 8) + 1024 */
-#if 0		// PATCH 1
-    codec->chunk_buffer_alloc = (codec->avctx->bit_rate * codec->avctx->frame_size /
-                                (codec->avctx->sample_rate * 8)) + 1024;
-#else
     codec->chunk_buffer_alloc = ( codec->avctx->frame_size
-									* sizeof( int16_t )
-									* codec->avctx->channels
-								);
-#endif
+                                  * sizeof( int16_t )
+                                  * codec->avctx->channels);
     codec->chunk_buffer = malloc(codec->chunk_buffer_alloc);
-
+    
     if(trak->strl)
-      {
-      /* strh stuff */
-      trak->strl->strh.dwRate = codec->avctx->bit_rate / 8;
-      trak->strl->strh.dwScale = 1;
-      trak->strl->strh.dwSampleSize = 1;
-      /* WAVEFORMATEX stuff */
-      
-      trak->strl->strf.wf.f.WAVEFORMAT.nBlockAlign = 1;
-      trak->strl->strf.wf.f.WAVEFORMAT.nAvgBytesPerSec =  codec->avctx->bit_rate / 8;
-      trak->strl->strf.wf.f.PCMWAVEFORMAT.wBitsPerSample = 0;
-      }
-
+      lqt_set_audio_bitrate(file, track, codec->avctx->bit_rate);
     }
 
   /* Allocate sample buffer if necessary */
 
-//         PATCH 2 
   if(codec->sample_buffer_alloc < (codec->samples_in_buffer + samples))
     {
     codec->sample_buffer_alloc = codec->samples_in_buffer + samples + 16;
@@ -913,7 +1157,7 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
 
   /* Interleave */
 
-  //  interleave(&(codec->sample_buffer[codec->samples_in_buffer * channels]),
+  //  interleave(&codec->sample_buffer[codec->samples_in_buffer * channels],
   //             input_i, input_f, samples, channels);
 
   memcpy(codec->sample_buffer + codec->samples_in_buffer * channels,
@@ -928,10 +1172,10 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
     
     frame_bytes = avcodec_encode_audio(codec->avctx, codec->chunk_buffer,
                                        codec->chunk_buffer_alloc,
-                                       &(codec->sample_buffer[samples_done*channels]));
+                                       &codec->sample_buffer[samples_done*channels]);
     if(frame_bytes > 0)
       {
-      quicktime_write_chunk_header(file, trak, &chunk_atom);
+      quicktime_write_chunk_header(file, trak);
 #if 0    // PATCH 3  
       if(codec->avctx->frame_size == 1)
         samples_encoded = codec->samples_in_buffer;
@@ -944,39 +1188,213 @@ static int lqt_ffmpeg_encode_audio(quicktime_t *file, void * input,
       codec->samples_in_buffer  -= samples_encoded;
       
       result = !quicktime_write_data(file, codec->chunk_buffer, frame_bytes);
-      quicktime_write_chunk_footer(file,
-                                   trak, 
-                                   file->atracks[track].cur_chunk,
-                                   &chunk_atom, 
-                                   samples_encoded);
+      trak->chunk_samples = samples_encoded;
+      quicktime_write_chunk_footer(file, trak);
       file->atracks[track].cur_chunk++;
       }
     }
   if(codec->samples_in_buffer && samples_done)
-    memmove(codec->sample_buffer, &(codec->sample_buffer[samples_done*channels]),
+    memmove(codec->sample_buffer, &codec->sample_buffer[samples_done*channels],
             codec->samples_in_buffer * sizeof(int16_t) * channels);
   return result;
   }
 
-void quicktime_init_audio_codec_ffmpeg(quicktime_audio_map_t *atrack, AVCodec *encoder,
+static int read_packet_mpa(quicktime_t * file, lqt_packet_t * p, int track)
+  {
+  mpa_header h;
+  uint8_t * ptr;
+  uint32_t header;
+  int chunk_size;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
+  
+  if(codec->bytes_in_chunk_buffer < 4)
+    {
+    chunk_size = lqt_append_audio_chunk(file,
+                                        track, track_map->cur_chunk,
+                                        &codec->chunk_buffer,
+                                        &codec->chunk_buffer_alloc,
+                                        codec->bytes_in_chunk_buffer);
+
+    //fprintf(stderr, "Got chunk %ld: %d bytes\n", track_map->cur_chunk, chunk_size);
+    
+    if(chunk_size + codec->bytes_in_chunk_buffer < 4)
+      return 0;
+
+    codec->bytes_in_chunk_buffer += chunk_size;
+    track_map->cur_chunk++;
+    }
+  
+  /* Check for mpa header */
+
+  ptr = codec->chunk_buffer;
+  while(1)
+    {
+    header =
+      ptr[3] | (ptr[2] << 8) | (ptr[1] << 16) | (ptr[0] << 24);
+    if(mpa_header_check(header))
+      break;
+    
+    ptr++;
+
+    if(ptr - codec->chunk_buffer > codec->bytes_in_chunk_buffer - 4)
+      return 0;
+    }
+
+  if(!mpa_decode_header(&h, ptr, NULL))
+    return 0;
+  
+  lqt_packet_alloc(p, h.frame_bytes);
+  memcpy(p->data, ptr, h.frame_bytes);
+  ptr += h.frame_bytes;
+  
+  codec->bytes_in_chunk_buffer -= (ptr - codec->chunk_buffer);
+
+  if(codec->bytes_in_chunk_buffer)
+    memmove(codec->chunk_buffer, ptr, codec->bytes_in_chunk_buffer);
+
+  p->duration = h.samples_per_frame;
+  p->timestamp = codec->pts;
+  codec->pts += p->duration;
+  p->flags = LQT_PACKET_KEYFRAME;
+  p->data_len = h.frame_bytes;
+  
+  return 1;
+  }
+
+static int writes_compressed_mp2(lqt_file_type_t type, const lqt_compression_info_t * ci)
+  {
+  return 1;
+  }
+
+static int init_compressed_mp2(quicktime_t * file, int track)
+  {
+  
+  return 0;
+  }
+
+#if 0
+static int init_compressed_ac3(quicktime_t * file, int track)
+  {
+  
+  return 0;
+  }
+#endif
+
+static int write_packet_ac3(quicktime_t * file, lqt_packet_t * p, int track)
+  {
+  int result;
+  quicktime_audio_map_t *atrack = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = atrack->codec->priv;
+  
+  if(!codec->header_written && (p->data_len >= 8))
+    {
+    if(file->file_type & (LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_MP4))
+      create_dac3_atom(file, track, p->data);
+    else if(file->file_type & (LQT_FILE_AVI | LQT_FILE_AVI_ODML))
+      lqt_set_audio_bitrate(file, track, atrack->ci.bitrate);
+    codec->header_written = 1;
+    }
+  
+  quicktime_write_chunk_header(file, atrack->track);
+  result = quicktime_write_data(file, p->data, p->data_len);
+  
+  atrack->track->chunk_samples = p->duration;
+  quicktime_write_chunk_footer(file, atrack->track);
+  atrack->cur_chunk++;
+  if(result)
+    return 0;
+  else
+    return 1;
+  
+  }
+
+static int read_packet_ac3(quicktime_t * file, lqt_packet_t * p, int track)
+  {
+  a52_header h;
+  uint8_t * ptr;
+  int chunk_size;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_ffmpeg_audio_codec_t *codec = track_map->codec->priv;
+  
+  if(codec->bytes_in_chunk_buffer < 8)
+    {
+    chunk_size = lqt_append_audio_chunk(file,
+                                        track, track_map->cur_chunk,
+                                        &codec->chunk_buffer,
+                                        &codec->chunk_buffer_alloc,
+                                        codec->bytes_in_chunk_buffer);
+
+    if(chunk_size + codec->bytes_in_chunk_buffer < 8)
+      return 0;
+
+    codec->bytes_in_chunk_buffer += chunk_size;
+    track_map->cur_chunk++;
+    }
+
+  /* Check for mpa header */
+
+  ptr = codec->chunk_buffer;
+  while(1)
+    {
+    if(a52_header_read(&h, ptr))
+      break;
+      
+    ptr++;
+
+    if(ptr - codec->chunk_buffer > codec->bytes_in_chunk_buffer - 8)
+      return 0;
+    }
+  
+  lqt_packet_alloc(p, h.frame_bytes);
+  memcpy(p->data, ptr, h.frame_bytes);
+  ptr += h.frame_bytes;
+
+  codec->bytes_in_chunk_buffer -= (ptr - codec->chunk_buffer);
+
+  if(codec->bytes_in_chunk_buffer)
+    memmove(codec->chunk_buffer, ptr, codec->bytes_in_chunk_buffer);
+
+  p->data_len = h.frame_bytes;
+  p->duration = A52_FRAME_SAMPLES;
+  p->timestamp = codec->pts;
+  codec->pts += p->duration;
+  p->flags = LQT_PACKET_KEYFRAME;
+  return 1;
+  }
+
+void quicktime_init_audio_codec_ffmpeg(quicktime_codec_t * codec_base,
+                                       quicktime_audio_map_t *atrack, AVCodec *encoder,
                                        AVCodec *decoder)
-{
-	quicktime_ffmpeg_audio_codec_t *codec;
+  {
+  quicktime_ffmpeg_audio_codec_t *codec;
+  
+  avcodec_init();
+  codec = calloc(1, sizeof(*codec));
+  if(!codec)
+    return;
+  
+  codec->encoder = encoder;
+  codec->decoder = decoder;
+  codec-> avctx = avcodec_alloc_context();
+  codec_base->priv = (void *)codec;
 
-	avcodec_init();
-	codec = calloc(1, sizeof(quicktime_ffmpeg_audio_codec_t));
-	if(!codec)
-          return;
+  codec_base->delete_codec = lqt_ffmpeg_delete_audio;
+  if(encoder)
+    codec_base->encode_audio = lqt_ffmpeg_encode_audio;
+  if(decoder)
+    codec_base->decode_audio = lqt_ffmpeg_decode_audio;
+  codec_base->set_parameter = set_parameter;
 
-	codec->encoder = encoder;
-	codec->decoder = decoder;
-	codec-> avctx = avcodec_alloc_context();
-	((quicktime_codec_t*)atrack->codec)->priv = (void *)codec;
-	((quicktime_codec_t*)atrack->codec)->delete_acodec = lqt_ffmpeg_delete_audio;
-	if(encoder)
-          ((quicktime_codec_t*)atrack->codec)->encode_audio = lqt_ffmpeg_encode_audio;
-	if(decoder)
-          ((quicktime_codec_t*)atrack->codec)->decode_audio = lqt_ffmpeg_decode_audio;
-	((quicktime_codec_t*)atrack->codec)->set_parameter = set_parameter;
-        atrack->sample_format = LQT_SAMPLE_INT16;
-}
+  if((decoder->id == CODEC_ID_MP3) || (decoder->id == CODEC_ID_MP2))
+    codec_base->read_packet = read_packet_mpa;
+  else if(decoder->id == CODEC_ID_AC3)
+    {
+    codec_base->write_packet = write_packet_ac3;
+    codec_base->read_packet = read_packet_ac3;
+    }
+  if(!atrack)
+    return;
+  
+  atrack->sample_format = LQT_SAMPLE_INT16;
+  }
