@@ -96,7 +96,8 @@ static lqt_codec_info_static_t codec_info_lame =
     .direction =           LQT_DIRECTION_ENCODE,
     .encoding_parameters = encode_parameters_lame,
     .decoding_parameters = (lqt_parameter_info_static_t*)0,
-    .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML
+    .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+    .compression_id      = LQT_COMPRESSION_MP3,
   };
 
 LQT_EXTERN int get_num_codecs() { return 1; }
@@ -113,9 +114,9 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
  *   Return the actual codec constructor
  */
 
-LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
   {
   if(index == 0)
     return quicktime_init_codec_lame;
-  return (lqt_init_audio_codec_func_t)0;
+  return (lqt_init_codec_func_t)0;
   }
