@@ -53,25 +53,25 @@ typedef struct
   int usefloat;
   } quicktime_jpeg_codec_t;
 
-static int delete_codec(quicktime_video_map_t *vtrack)
-{
-	quicktime_jpeg_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-        if(codec->mjpeg)
-          mjpeg_delete(codec->mjpeg);
-	if(codec->buffer)
-		free(codec->buffer);
-	if(codec->temp_video)
-		free(codec->temp_video);
-	free(codec);
-	return 0;
-}
+static int delete_codec(quicktime_codec_t *codec_base)
+  {
+  quicktime_jpeg_codec_t *codec = codec_base->priv;
+  if(codec->mjpeg)
+    mjpeg_delete(codec->mjpeg);
+  if(codec->buffer)
+    free(codec->buffer);
+  if(codec->temp_video)
+    free(codec->temp_video);
+  free(codec);
+  return 0;
+  }
 
 static int decode(quicktime_t *file, 
                   unsigned char **row_pointers, 
                   int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_jpeg_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_jpeg_codec_t *codec = vtrack->codec->priv;
   mjpeg_t *mjpeg;
   long size, field2_offset;
   int result = 0;
@@ -121,6 +121,10 @@ static int decode(quicktime_t *file,
       /* Detect colormodel and return */
       vtrack->stream_cmodel = mjpeg->jpeg_color_model;
       codec->have_frame = 1;
+
+      /* Set compression info */
+      if(file->file_type & (LQT_FILE_QT | LQT_FILE_QT_OLD))
+        vtrack->ci.id = LQT_COMPRESSION_JPEG;
       return 0;
       }
     }
@@ -137,27 +141,39 @@ static int decode(quicktime_t *file,
   return result;
   }
 
+static int writes_compressed(lqt_file_type_t type, const lqt_compression_info_t * ci)
+  {
+  if((ci->colormodel == BC_YUVJ444P) ||
+     (ci->colormodel == BC_YUVJ422P) ||
+     (ci->colormodel == BC_YUVJ420P))
+    return 1;
+  else
+    return 0;
+  }
+
+  
 static void resync(quicktime_t *file, int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_jpeg_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_jpeg_codec_t *codec = vtrack->codec->priv;
   codec->have_frame = 0;
   }
      
 static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_jpeg_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_jpeg_codec_t *codec = vtrack->codec->priv;
   quicktime_trak_t *trak = vtrack->track;
   int result = 0;
   long field2_offset;
 
   if(!row_pointers)
     {
-    if(codec->jpeg_type == JPEG_PROGRESSIVE)
-      vtrack->stream_cmodel = BC_YUVJ420P;
-    else
+    if(codec->jpeg_type != JPEG_PROGRESSIVE)
       vtrack->stream_cmodel = BC_YUVJ422P;
+    else
+      vtrack->stream_cmodel = BC_YUVJ420P;
+      
     return 0;
     }
         
@@ -227,45 +243,48 @@ static int set_parameter(quicktime_t *file,
                          const char *key, 
                          const void *value)
   {
-  quicktime_jpeg_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
+  quicktime_jpeg_codec_t *codec = file->vtracks[track].codec->priv;
 	
   if(!strcasecmp(key, "jpeg_quality"))
     {
     codec->quality = *(int*)value;
     }
-  else
-    if(!strcasecmp(key, "jpeg_usefloat"))
-      {
-      codec->usefloat = *(int*)value;
-      }
+  else if(!strcasecmp(key, "jpeg_usefloat"))
+    {
+    codec->usefloat = *(int*)value;
+    }
   return 0;
   }
 
-void quicktime_init_codec_jpeg(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_jpeg(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
   {
-  char *compressor = vtrack->track->mdia.minf.stbl.stsd.table[0].format;
+  char *compressor;
   quicktime_jpeg_codec_t *codec;
-  int jpeg_type=0;
-
-  if(quicktime_match_32(compressor, QUICKTIME_JPEG))
-    {
-    jpeg_type = JPEG_PROGRESSIVE;
-    }
-  if(quicktime_match_32(compressor, QUICKTIME_MJPA))
-    {
-    jpeg_type = JPEG_MJPA;
-    }
+  
   /* Init public items */
-  ((quicktime_codec_t*)vtrack->codec)->priv = lqt_bufalloc(sizeof(quicktime_jpeg_codec_t));
-  ((quicktime_codec_t*)vtrack->codec)->delete_vcodec = delete_codec;
-  ((quicktime_codec_t*)vtrack->codec)->decode_video = decode;
-  ((quicktime_codec_t*)vtrack->codec)->encode_video = encode;
-  ((quicktime_codec_t*)vtrack->codec)->set_parameter = set_parameter;
-  ((quicktime_codec_t*)vtrack->codec)->resync = resync;
-
+  codec = calloc(1, sizeof(*codec));
+  
+  codec_base->priv = codec;
+  codec_base->delete_codec = delete_codec;
+  codec_base->decode_video = decode;
+  codec_base->encode_video = encode;
+  codec_base->set_parameter = set_parameter;
+  codec_base->resync = resync;
+  codec_base->writes_compressed = writes_compressed;
+  
   /* Init private items */
-  codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-  codec->jpeg_type = jpeg_type;
   codec->quality = 80;
   codec->usefloat = 0;
+
+  if(!vtrack)
+    return;
+
+  compressor = vtrack->track->mdia.minf.stbl.stsd.table[0].format;
+  
+  if(quicktime_match_32(compressor, QUICKTIME_JPEG))
+    codec->jpeg_type = JPEG_PROGRESSIVE;
+  else if(quicktime_match_32(compressor, QUICKTIME_MJPA))
+    codec->jpeg_type = JPEG_MJPA;
   }
