@@ -85,10 +85,10 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
  *   Return the actual codec constructor
  */
 
-LQT_EXTERN lqt_init_video_codec_func_t get_video_codec(int index)
-{
-	if(index == 0)
-		return quicktime_init_codec_rtjpeg;
-	return (lqt_init_video_codec_func_t)0;
-}
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
+  {
+  if(index == 0)
+    return quicktime_init_codec_rtjpeg;
+  return (lqt_init_codec_func_t)0;
+  }
 
