@@ -107,15 +107,16 @@ typedef struct
   int buffer_alloc;
   } quicktime_v408_codec_t;
 
-static int delete_codec(quicktime_video_map_t *vtrack)
-{
-	quicktime_v408_codec_t *codec;
-
-	codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-	if(codec->buffer) free(codec->buffer);
-	free(codec);
-	return 0;
-}
+static int delete_codec(quicktime_codec_t *codec_base)
+  {
+  quicktime_v408_codec_t *codec;
+  
+  codec = codec_base->priv;
+  if(codec->buffer)
+    free(codec->buffer);
+  free(codec);
+  return 0;
+  }
 
 static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 {
@@ -123,8 +124,8 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
         int i, j;
 	int64_t bytes;
 	int result = 0;
-	quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-	quicktime_v408_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+	quicktime_video_map_t *vtrack = &file->vtracks[track];
+	quicktime_v408_codec_t *codec = vtrack->codec->priv;
 	int width = vtrack->track->tkhd.track_width;
 	int height = vtrack->track->tkhd.track_height;
 
@@ -163,8 +164,8 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 {
         uint8_t * in_ptr, *out_ptr;
-	quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-	quicktime_v408_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+	quicktime_video_map_t *vtrack = &file->vtracks[track];
+	quicktime_v408_codec_t *codec = vtrack->codec->priv;
 	int width = vtrack->track->tkhd.track_width;
 	int height = vtrack->track->tkhd.track_height;
 	int bytes = width * height * 4;
@@ -180,6 +181,7 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
         if(!codec->buffer)
           {
           lqt_set_fiel_uncompressed(file, track);
+          lqt_set_colr_yuv_uncompressed(file, track);
           codec->buffer = malloc(width * height * 4);
           }
         out_ptr = codec->buffer;
@@ -209,16 +211,14 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 	return result;
 }
 
-void quicktime_init_codec_v408(quicktime_video_map_t *vtrack)
-{
-	quicktime_codec_t *codec_base = (quicktime_codec_t*)vtrack->codec;
-
-/* Init public items */
-	codec_base->priv = calloc(1, sizeof(quicktime_v408_codec_t));
-	codec_base->delete_vcodec = delete_codec;
-	codec_base->decode_video = decode;
-	codec_base->encode_video = encode;
-	codec_base->decode_audio = 0;
-	codec_base->encode_audio = 0;
-}
+void quicktime_init_codec_v408(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
+  {
+  /* Init public items */
+  codec_base->priv = calloc(1, sizeof(quicktime_v408_codec_t));
+  codec_base->delete_codec = delete_codec;
+  codec_base->decode_video = decode;
+  codec_base->encode_video = encode;
+  }
 
