@@ -55,13 +55,15 @@ typedef struct
   uint8_t ** rows;
   } quicktime_yuv2_codec_t;
 
-static int quicktime_delete_codec_yuv2(quicktime_video_map_t *vtrack)
+static int quicktime_delete_codec_yuv2(quicktime_codec_t *codec_base)
   {
   quicktime_yuv2_codec_t *codec;
 
-  codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-  if(codec->buffer) free(codec->buffer);
-  if(codec->rows) free(codec->rows);
+  codec = codec_base->priv;
+  if(codec->buffer)
+    free(codec->buffer);
+  if(codec->rows)
+    free(codec->rows);
   free(codec);
   return 0;
   }
@@ -187,8 +189,8 @@ static void initialize(quicktime_video_map_t *vtrack, quicktime_yuv2_codec_t *co
 static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
   {
   int64_t bytes;
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_yuv2_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_yuv2_codec_t *codec = vtrack->codec->priv;
   int width = quicktime_video_width(file, track);
   int height = quicktime_video_height(file, track);
   int result = 0;
@@ -218,8 +220,8 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 
 static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_yuv2_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_yuv2_codec_t *codec = vtrack->codec->priv;
   int result = 1;
   int width = vtrack->track->tkhd.track_width;
   int height = vtrack->track->tkhd.track_height;
@@ -236,7 +238,10 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
     }
 
   if(!codec->initialized)
+    {
     lqt_set_fiel_uncompressed(file, track);
+    lqt_set_colr_yuv_uncompressed(file, track);
+    }
         
   initialize(vtrack, codec, width, height);
 
@@ -260,31 +265,28 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   }
 
 
-void quicktime_init_codec_yuv2(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_yuv2(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
   {
-  quicktime_codec_t *codec_base = (quicktime_codec_t*)vtrack->codec;
-
   /* Init public items */
   codec_base->priv = calloc(1, sizeof(quicktime_yuv2_codec_t));
-  codec_base->delete_vcodec = quicktime_delete_codec_yuv2;
+  codec_base->delete_codec = quicktime_delete_codec_yuv2;
   codec_base->decode_video = decode;
   codec_base->encode_video = encode;
-  codec_base->decode_audio = 0;
-  codec_base->encode_audio = 0;
   }
 
-void quicktime_init_codec_2vuy(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_2vuy(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
   {
-  quicktime_codec_t *codec_base = (quicktime_codec_t*)vtrack->codec;
   quicktime_yuv2_codec_t * codec;
+  codec = calloc(1, sizeof(*codec));
   /* Init public items */
-  codec_base->priv = calloc(1, sizeof(quicktime_yuv2_codec_t));
-  codec_base->delete_vcodec = quicktime_delete_codec_yuv2;
+  codec_base->priv = codec;
+  codec_base->delete_codec = quicktime_delete_codec_yuv2;
   codec_base->decode_video = decode;
   codec_base->encode_video = encode;
-  codec_base->decode_audio = 0;
-  codec_base->encode_audio = 0;
-  codec = (quicktime_yuv2_codec_t *)(codec_base->priv);
   codec->is_2vuy = 1;
   }
 
