@@ -63,13 +63,14 @@ typedef struct
   int initialized;
   } quicktime_yuv4_codec_t;
 
-static int quicktime_delete_codec_yuv4(quicktime_video_map_t *vtrack)
-{
-	quicktime_yuv4_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-	free(codec->buffer);
-	free(codec);
-	return 0;
-}
+static int quicktime_delete_codec_yuv4(quicktime_codec_t *codec_base)
+  {
+  quicktime_yuv4_codec_t *codec = codec_base->priv;
+  if(codec->buffer)
+    free(codec->buffer);
+  free(codec);
+  return 0;
+  }
 
 
 static void initialize(quicktime_video_map_t *vtrack, quicktime_yuv4_codec_t *codec)
@@ -94,10 +95,10 @@ static void initialize(quicktime_video_map_t *vtrack, quicktime_yuv4_codec_t *co
 			codec->btov_tab[i] = (long)(-0.0813 * 65536 * i);
 		}
 
-		codec->vtor = &(codec->vtor_tab[128]);
-		codec->vtog = &(codec->vtog_tab[128]);
-		codec->utog = &(codec->utog_tab[128]);
-		codec->utob = &(codec->utob_tab[128]);
+		codec->vtor = &codec->vtor_tab[128];
+		codec->vtog = &codec->vtog_tab[128];
+		codec->utog = &codec->utog_tab[128];
+		codec->utob = &codec->utob_tab[128];
 		for(i = -128; i < 128; i++)
 		{
 /* decompression */
@@ -125,8 +126,8 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 {
 	int64_t bytes, in_y, out_y;
 	register int x1, x2;
-	quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-	quicktime_yuv4_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+	quicktime_video_map_t *vtrack = &file->vtracks[track];
+	quicktime_yuv4_codec_t *codec = vtrack->codec->priv;
 	int width = vtrack->track->tkhd.track_width;
 	int height = vtrack->track->tkhd.track_height;
 	unsigned char *buffer;
@@ -250,8 +251,8 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 
 static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 {
-	quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-	quicktime_yuv4_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+	quicktime_video_map_t *vtrack = &file->vtracks[track];
+	quicktime_yuv4_codec_t *codec = vtrack->codec->priv;
 	int result = 0;
 	int width = vtrack->track->tkhd.track_width;
 	int height = vtrack->track->tkhd.track_height;
@@ -381,17 +382,15 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 }
 
 
-void quicktime_init_codec_yuv4(quicktime_video_map_t *vtrack)
-{
-	quicktime_codec_t *codec_base = (quicktime_codec_t*)vtrack->codec;
-
-/* Init public items */
-	codec_base->priv = calloc(1, sizeof(quicktime_yuv4_codec_t));
-	codec_base->delete_vcodec = quicktime_delete_codec_yuv4;
-	codec_base->decode_video = decode;
-	codec_base->encode_video = encode;
-	codec_base->decode_audio = 0;
-	codec_base->encode_audio = 0;
-}
+void quicktime_init_codec_yuv4(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
+  {
+  /* Init public items */
+  codec_base->priv = calloc(1, sizeof(quicktime_yuv4_codec_t));
+  codec_base->delete_codec = quicktime_delete_codec_yuv4;
+  codec_base->decode_video = decode;
+  codec_base->encode_video = encode;
+  }
 
 
