@@ -33,92 +33,92 @@
 #define LOG_DOMAIN "vorbis"
 
 typedef struct
-{
+  {
+  int channels;
+  
+  /* Common stuff */
+  float ** sample_buffer;
+  int sample_buffer_alloc; 
+  /* Encoder stuff */
+  int max_bitrate;
+  int nominal_bitrate;
+  int min_bitrate;
+  int use_vbr;
+  int write_OVHS;
+  int encode_initialized;
+  ogg_stream_state enc_os;
+  ogg_page enc_og;
+  uint8_t * enc_header;
+  int enc_header_len;
+  int header_written;
 
-/* Common stuff */
-        float ** sample_buffer;
-        int sample_buffer_alloc; 
-/* Encoder stuff */
-        int max_bitrate;
-	int nominal_bitrate;
-	int min_bitrate;
-	int use_vbr;
-        int write_OVHS;
-        int encode_initialized;
-	ogg_stream_state enc_os;
-	ogg_page enc_og;
-        uint8_t * enc_header;
-        int enc_header_len;
-        int header_written;
+  ogg_packet enc_op;
+  vorbis_info enc_vi;
+  vorbis_comment enc_vc;
+  vorbis_dsp_state enc_vd;
+  vorbis_block enc_vb;
+  //        int64_t last_granulepos;
 
-ogg_packet enc_op;
-	vorbis_info enc_vi;
-	vorbis_comment enc_vc;
-	vorbis_dsp_state enc_vd;
-	vorbis_block enc_vb;
-//        int64_t last_granulepos;
+  // Number of samples written to disk
+  int encoded_samples;
 
-// Number of samples written to disk
-	int encoded_samples;
+  int enc_samples_in_buffer;
 
-        int enc_samples_in_buffer;
+  quicktime_atom_t chunk_atom;
 
-        int chunk_started;
-        quicktime_atom_t chunk_atom;
+  /* Decoder stuff */
 
-/* Decoder stuff */
+  ogg_sync_state   dec_oy; /* sync and verify incoming physical bitstream */
+  ogg_stream_state dec_os; /* take physical pages, weld into a logical
+                              stream of packets */
+  ogg_page         dec_og; /* one Ogg bitstream page.  Vorbis packets are inside */
+  ogg_packet       dec_op; /* one raw packet of data for decode */
 
-	ogg_sync_state   dec_oy; /* sync and verify incoming physical bitstream */
-	ogg_stream_state dec_os; /* take physical pages, weld into a logical
-				stream of packets */
-	ogg_page         dec_og; /* one Ogg bitstream page.  Vorbis packets are inside */
-	ogg_packet       dec_op; /* one raw packet of data for decode */
+  vorbis_info      dec_vi; /* struct that stores all the static vorbis bitstream
+                              settings */
+  vorbis_comment   dec_vc; /* struct that stores all the bitstream user comments */
+  vorbis_dsp_state dec_vd; /* central working state for the packet->PCM decoder */
+  vorbis_block     dec_vb; /* local working space for packet->PCM decode */
 
-	vorbis_info      dec_vi; /* struct that stores all the static vorbis bitstream
-				settings */
-	vorbis_comment   dec_vc; /* struct that stores all the bitstream user comments */
-	vorbis_dsp_state dec_vd; /* central working state for the packet->PCM decoder */
-	vorbis_block     dec_vb; /* local working space for packet->PCM decode */
-
-	int decode_initialized;
-        int stream_initialized;
+  int decode_initialized;
+  int stream_initialized;
 
   
   /* Buffer for the entire chunk */
 
-        uint8_t * chunk_buffer;
-        int chunk_buffer_alloc;
-        int bytes_in_chunk_buffer;
+  uint8_t * chunk_buffer;
+  int chunk_buffer_alloc;
+  int bytes_in_chunk_buffer;
 
   /* Start and end positions of the sample buffer */
     
-        int64_t sample_buffer_start;
-        int64_t sample_buffer_end;
+  int64_t sample_buffer_start;
+  int64_t sample_buffer_end;
 
 
-// Number of last sample relative to file
-	int64_t output_position;
-// Number of last sample relative to output buffer
-	long output_end;
-// Number of samples in output buffer
-	long output_size;
-// Number of samples allocated in output buffer
-	long output_allocated;
-// Current reading position in file
-	int64_t chunk;
-// Number of samples decoded in the current chunk
-	int chunk_samples;
+  // Number of last sample relative to file
+  int64_t output_position;
+  // Number of last sample relative to output buffer
+  long output_end;
+  // Number of samples in output buffer
+  long output_size;
+  // Number of samples allocated in output buffer
+  long output_allocated;
+  // Current reading position in file
+  int64_t chunk;
+  // Number of samples decoded in the current chunk
+  int chunk_samples;
 
-        int header_read;
+  int header_read;
 
   } quicktime_vorbis_codec_t;
 
 
 /* =================================== public for vorbis */
 
-static int delete_codec(quicktime_audio_map_t *atrack)
+static int delete_codec(quicktime_codec_t *codec_base)
   {
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)atrack->codec)->priv;
+  quicktime_vorbis_codec_t *codec = codec_base->priv;
   int i;
 
   if(codec->encode_initialized)
@@ -141,7 +141,7 @@ static int delete_codec(quicktime_audio_map_t *atrack)
 
   if(codec->sample_buffer) 
     {
-    for(i = 0; i < atrack->channels; i++)
+    for(i = 0; i < codec->channels; i++)
       free(codec->sample_buffer[i]);
     free(codec->sample_buffer);
     }
@@ -164,8 +164,8 @@ static int next_chunk(quicktime_t * file, int track)
   uint8_t * header;
   uint32_t header_len;
 
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
 
   if(!codec->header_read) /* Try OVHS atom */
     {
@@ -191,8 +191,8 @@ static int next_chunk(quicktime_t * file, int track)
     for(i = 0; i < num_packets; i++)
       {
       chunk_size = lqt_audio_read_vbr_packet(file, track, track_map->cur_chunk, i,
-                                             &(codec->chunk_buffer),
-                                             &(codec->chunk_buffer_alloc), &samples);
+                                             &codec->chunk_buffer,
+                                             &codec->chunk_buffer_alloc, &samples);
       buffer = ogg_sync_buffer(&codec->dec_oy, chunk_size);
       memcpy(buffer, codec->chunk_buffer, chunk_size);
       ogg_sync_wrote(&codec->dec_oy, chunk_size);
@@ -202,8 +202,8 @@ static int next_chunk(quicktime_t * file, int track)
     {
     chunk_size = lqt_read_audio_chunk(file,
                                       track, track_map->cur_chunk,
-                                      &(codec->chunk_buffer),
-                                      &(codec->chunk_buffer_alloc), (int*)0);
+                                      &codec->chunk_buffer,
+                                      &codec->chunk_buffer_alloc, (int*)0);
     if(chunk_size <= 0)
       {
       return 0;
@@ -221,8 +221,8 @@ static int next_chunk(quicktime_t * file, int track)
 
 static int next_page(quicktime_t * file, int track)
   {
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   int result = 0;
   
   while(result < 1)
@@ -252,8 +252,8 @@ static int next_page(quicktime_t * file, int track)
 
 static int next_packet(quicktime_t * file, int track)
   {
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
 
   int result = 0;
   while(result < 1)
@@ -270,7 +270,7 @@ static int next_packet(quicktime_t * file, int track)
   }
 
 static float ** alloc_sample_buffer(float ** old, int channels, int samples,
-                             int * sample_buffer_alloc)
+                                    int * sample_buffer_alloc)
   {
   int i;
   if(!old)
@@ -280,7 +280,8 @@ static float ** alloc_sample_buffer(float ** old, int channels, int samples,
   if(*sample_buffer_alloc < samples)
     {
     *sample_buffer_alloc = samples + 256;
-
+    
+    
     for(i = 0; i < channels; i++)
       {
       old[i] = realloc(old[i], (*sample_buffer_alloc) * sizeof(float));
@@ -295,12 +296,12 @@ static int decode_frame(quicktime_t * file, int track)
   int i;
   float ** channels;
   int samples_decoded = 0;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
 
   while(1)
     {
-    samples_decoded = vorbis_synthesis_pcmout(&codec->dec_vd, &(channels));
+    samples_decoded = vorbis_synthesis_pcmout(&codec->dec_vd, &channels);
 
     if(samples_decoded > 0)
       break;
@@ -323,7 +324,7 @@ static int decode_frame(quicktime_t * file, int track)
                                              file->atracks[track].channels,
                                              codec->sample_buffer_end -
                                              codec->sample_buffer_start + samples_decoded,
-                                             &(codec->sample_buffer_alloc));
+                                             &codec->sample_buffer_alloc);
 
   for(i = 0; i < track_map->channels; i++)
     {
@@ -343,8 +344,8 @@ static int decode(quicktime_t *file,
   {
   int i, j;
   int64_t chunk_sample; /* For seeking only */
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   //  int64_t total_samples;
   int samples_decoded;
   int samples_to_skip;
@@ -361,7 +362,8 @@ static int decode(quicktime_t *file,
   if(!codec->decode_initialized)
     {
     codec->decode_initialized = 1;
-
+    codec->channels = track_map->channels;
+    
     ogg_sync_init(&codec->dec_oy); /* Now we can read pages */
 
     vorbis_info_init(&codec->dec_vi);
@@ -419,12 +421,12 @@ static int decode(quicktime_t *file,
 
     if(lqt_audio_is_vbr(file, track))
       lqt_chunk_of_sample_vbr(&chunk_sample,
-                              &(track_map->cur_chunk),
+                              &track_map->cur_chunk,
                               track_map->track,
                               track_map->current_position);
     else
       quicktime_chunk_of_sample(&chunk_sample,
-                                &(track_map->cur_chunk),
+                                &track_map->cur_chunk,
                                 track_map->track,
                                 track_map->current_position);
       
@@ -480,7 +482,7 @@ static int decode(quicktime_t *file,
       for(i = 0; i < track_map->channels; i++)
         {
         memmove(codec->sample_buffer[i],
-                &(codec->sample_buffer[i][samples_to_skip]),
+                &codec->sample_buffer[i][samples_to_skip],
                 samples_to_move * sizeof(float));
         }
       }
@@ -526,8 +528,8 @@ static int decode(quicktime_t *file,
 
 static int flush_header(quicktime_t * file, int track)
   {
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   while(ogg_stream_flush(&codec->enc_os, &codec->enc_og))
     {
     codec->enc_header = realloc(codec->enc_header, codec->enc_header_len +
@@ -558,9 +560,9 @@ static int flush_data(quicktime_t * file, int track)
   {
   int64_t new_encoded_samples;
   int result = 0;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
+  quicktime_audio_map_t *track_map = &file->atracks[track];
   quicktime_trak_t *trak = track_map->track;
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   
   while(vorbis_analysis_blockout(&codec->enc_vd, &codec->enc_vb) == 1)
     {
@@ -586,12 +588,9 @@ static int flush_data(quicktime_t * file, int track)
     if(!ogg_stream_flush(&codec->enc_os, &codec->enc_og))
       break;
 
-    if(!codec->chunk_started)
-      {
-      codec->chunk_started = 1;
-      lqt_start_audio_vbr_chunk(file, track);
-      quicktime_write_chunk_header(file, trak, &codec->chunk_atom);
-      }
+    if(file->write_trak != trak)
+      quicktime_write_chunk_header(file, trak);
+    
     lqt_start_audio_vbr_frame(file, track);
     if(!codec->header_written)
       {
@@ -606,7 +605,8 @@ static int flush_data(quicktime_t * file, int track)
       }
     new_encoded_samples = codec->enc_os.granulepos;
 
-    lqt_finish_audio_vbr_frame(file, track, new_encoded_samples - codec->encoded_samples);
+    lqt_finish_audio_vbr_frame(file, track,
+                               new_encoded_samples - codec->encoded_samples);
     codec->encoded_samples = new_encoded_samples;
     
     
@@ -617,8 +617,8 @@ static int flush_data(quicktime_t * file, int track)
 
 static void flush_audio(quicktime_t * file, int track)
   {
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   
   float ** output;
   int i;
@@ -641,9 +641,9 @@ static int encode(quicktime_t *file,
   int i, j;
   int samples_copied, samples_to_copy;
   int result = 0;
-  quicktime_audio_map_t *track_map = &(file->atracks[track]);
+  quicktime_audio_map_t *track_map = &file->atracks[track];
   quicktime_trak_t *trak = track_map->track;
-  quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
   int samplerate = track_map->samplerate;
   float * input;
   
@@ -655,7 +655,7 @@ static int encode(quicktime_t *file,
 
  
     codec->encode_initialized = 1;
-
+    codec->channels = track_map->channels;
     lqt_init_vbr_audio(file, track);
 
 
@@ -734,15 +734,10 @@ static int encode(quicktime_t *file,
   result = 0;
 
   // Wrote a chunk.
-  if(codec->chunk_started)
+  if(file->write_trak == trak)
     {
-    quicktime_write_chunk_footer(file, 
-                                 trak,
-                                 track_map->cur_chunk,
-                                 &codec->chunk_atom, 
-                                 track_map->vbr_num_frames);
+    quicktime_write_chunk_footer(file, trak);
     track_map->cur_chunk++;
-    codec->chunk_started = 0;
     }
 
   return result;
@@ -756,8 +751,8 @@ static int set_parameter(quicktime_t *file,
 		const char *key, 
 		const void *value)
 {
-	quicktime_audio_map_t *atrack = &(file->atracks[track]);
-	quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)atrack->codec)->priv;
+	quicktime_audio_map_t *atrack = &file->atracks[track];
+	quicktime_vorbis_codec_t *codec = atrack->codec->priv;
 
 	if(!strcasecmp(key, "vorbis_vbr"))
 		codec->use_vbr = *(int*)value;
@@ -775,69 +770,70 @@ static int set_parameter(quicktime_t *file,
 
 
 static int flush(quicktime_t *file, int track)
-{
-	quicktime_audio_map_t *track_map = &(file->atracks[track]);
-	quicktime_vorbis_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
-	quicktime_trak_t *trak = track_map->track;
+  {
+  quicktime_audio_map_t *track_map = &file->atracks[track];
+  quicktime_vorbis_codec_t *codec = track_map->codec->priv;
+  quicktime_trak_t *trak = track_map->track;
 
-        flush_audio(file, track);
-	vorbis_analysis_wrote(&codec->enc_vd,0);
+  flush_audio(file, track);
+  vorbis_analysis_wrote(&codec->enc_vd,0);
 
-        flush_data(file, track);
+  flush_data(file, track);
         
-        //	FLUSH_OGG2
+  //	FLUSH_OGG2
 	
-	if(codec->chunk_started)
-	{
-        quicktime_write_chunk_footer(file, 
-                                     trak,
-                                     track_map->cur_chunk,
-                                     &codec->chunk_atom, 
-                                     track_map->vbr_num_frames);
-        track_map->cur_chunk++;
-        codec->chunk_started = 0;
-        return 1;
-	}
-        return 0;
-}
+  if(file->write_trak == trak)
+    {
+    quicktime_write_chunk_footer(file, trak);
+    track_map->cur_chunk++;
+    return 1;
+    }
+  return 0;
+  }
 
-void quicktime_init_codec_vorbis(quicktime_audio_map_t *atrack)
-{
-	quicktime_codec_t *codec_base = (quicktime_codec_t*)atrack->codec;
-	quicktime_vorbis_codec_t *codec;
-	char *compressor = atrack->track->mdia.minf.stbl.stsd.table[0].format;
+void quicktime_init_codec_vorbis(quicktime_codec_t *codec_base,
+                                 quicktime_audio_map_t *atrack,
+                                 quicktime_video_map_t *vtrack)
+  {
+  quicktime_vorbis_codec_t *codec;
+  char *compressor = atrack->track->mdia.minf.stbl.stsd.table[0].format;
 
-/* Init public items */
-	codec_base->priv = calloc(1, sizeof(quicktime_vorbis_codec_t));
-	codec_base->delete_acodec = delete_codec;
-	codec_base->decode_audio = decode;
-	codec_base->encode_audio = encode;
-	codec_base->set_parameter = set_parameter;
-	codec_base->flush = flush;
+  /* Init public items */
+  codec = calloc(1, sizeof(*codec));
+  
+  codec_base->priv = codec;
+  codec_base->delete_codec = delete_codec;
+  codec_base->decode_audio = decode;
+  codec_base->encode_audio = encode;
+  codec_base->set_parameter = set_parameter;
+  codec_base->flush = flush;
         
-	codec = codec_base->priv;
-	codec->nominal_bitrate = 128000;
-	codec->max_bitrate = -1;
-	codec->min_bitrate = -1;
-        atrack->sample_format = LQT_SAMPLE_FLOAT;
-        if(quicktime_match_32(compressor, "OggV"))
-          {
-          codec->write_OVHS = 1;
-          }
-        /* Set Vorbis 5.1 channel mapping */
-        if(atrack->channels == 6)
-          {
-          if(!atrack->channel_setup)
-            {
-            atrack->channel_setup = calloc(6, sizeof(*atrack->channel_setup));
-            atrack->channel_setup[0] =  LQT_CHANNEL_FRONT_LEFT;
-            atrack->channel_setup[1] =  LQT_CHANNEL_FRONT_CENTER;
-            atrack->channel_setup[2] =  LQT_CHANNEL_FRONT_RIGHT;
-            atrack->channel_setup[3] =  LQT_CHANNEL_LFE;
-            atrack->channel_setup[4] =  LQT_CHANNEL_BACK_LEFT;
-            atrack->channel_setup[5] =  LQT_CHANNEL_BACK_RIGHT;
+  codec->nominal_bitrate = 128000;
+  codec->max_bitrate = -1;
+  codec->min_bitrate = -1;
+  
+  if(!atrack)
+    return;
+  
+  atrack->sample_format = LQT_SAMPLE_FLOAT;
+  if(quicktime_match_32(compressor, "OggV"))
+    {
+    codec->write_OVHS = 1;
+    }
+  /* Set Vorbis 5.1 channel mapping */
+  if(atrack->channels == 6)
+    {
+    if(!atrack->channel_setup)
+      {
+      atrack->channel_setup = calloc(6, sizeof(*atrack->channel_setup));
+      atrack->channel_setup[0] =  LQT_CHANNEL_FRONT_LEFT;
+      atrack->channel_setup[1] =  LQT_CHANNEL_FRONT_CENTER;
+      atrack->channel_setup[2] =  LQT_CHANNEL_FRONT_RIGHT;
+      atrack->channel_setup[3] =  LQT_CHANNEL_LFE;
+      atrack->channel_setup[4] =  LQT_CHANNEL_BACK_LEFT;
+      atrack->channel_setup[5] =  LQT_CHANNEL_BACK_RIGHT;
 
-            }
-          }
+      }
+    }
 
-}
+  }
