@@ -26,7 +26,7 @@
 
 int quicktime_imgp_init(quicktime_imgp_t *imgp)
 {
-    	quicktime_impn_init(&(imgp->impn));
+    	quicktime_impn_init(&imgp->impn);
 	return 0;
 }
 
@@ -38,7 +38,7 @@ int quicktime_imgp_delete(quicktime_imgp_t *imgp)
 void quicktime_imgp_dump(quicktime_imgp_t *imgp)
 {
 	lqt_dump("        Imaging Parent (imgp)\n");
-	quicktime_impn_dump(&(imgp->impn));
+	quicktime_impn_dump(&imgp->impn);
 
 }
 
@@ -52,7 +52,7 @@ int quicktime_read_imgp(quicktime_t *file, quicktime_imgp_t *imgp, quicktime_qta
 	    	quicktime_qtatom_read_header(file, &leaf_atom);
 		if(quicktime_qtatom_is(&leaf_atom, "impn"))
 		{
-		    	result += quicktime_read_impn(file, &(imgp->impn), &leaf_atom);
+		    	result += quicktime_read_impn(file, &imgp->impn, &leaf_atom);
 		} else
 			quicktime_qtatom_skip(file, &leaf_atom);
 	}while(quicktime_position(file) < imgp_atom->end);
@@ -64,7 +64,7 @@ void quicktime_write_imgp(quicktime_t *file, quicktime_imgp_t *imgp )
 {
 	quicktime_qtatom_t atom;
 	quicktime_qtatom_write_header(file, &atom, "imgp", 1);
-	quicktime_write_impn(file, &(imgp->impn));
+	quicktime_write_impn(file, &imgp->impn);
 
 	atom.child_count = 1;
 	
